from setuptools import setup

setup(name='ftThanos',
version="0.0.73",
description="A client for 73 API",
author="Thanos 73",
author_email="thanos@73paris.fr",
packages=["ftThanos"],
install_requires=["requests","python-dotenv"],
)
